import { jsx as _jsx } from "react/jsx-runtime";
import { styled } from "@mui/material";
import { DateCalendar } from "@mui/x-date-pickers/DateCalendar";
import { PickersDay } from "@mui/x-date-pickers/PickersDay";
import { useEffect, useState } from "react";
import { isDateSelected, isSameDay } from "./utils";
function MultiDateSelector(props) {
    const { defaultDates, onSelectedDatesChange, onDateSelected, onDateUnselected, ...others } = props;
    const [selectedDates, setSelectedDates] = useState(defaultDates || []);
    function handleSelectDate(value) {
        if (!value)
            return;
        setSelectedDates(function (prev) {
            if (isDateSelected(selectedDates, value)) {
                const unselectedDateIndex = prev.findIndex((it) => isSameDay(it, value));
                const unselectedDate = prev[unselectedDateIndex];
                onDateUnselected?.(unselectedDate);
                return [...prev.filter((_, id) => id !== unselectedDateIndex)];
            }
            onDateSelected?.(value);
            return [...prev, value];
        });
    }
    useEffect(() => {
        onSelectedDatesChange?.(selectedDates);
    }, [selectedDates, onSelectedDatesChange]);
    return (_jsx(DateCalendar, { slots: { day: DaySlot }, onChange: handleSelectDate, disableHighlightToday: true, slotProps: {
            day: (ownerState) => ({
                isSelected: isDateSelected(selectedDates, ownerState.day),
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
            }),
        }, ...others }));
}
export default MultiDateSelector;
function DaySlot(props) {
    const { day, isSelected, ...other } = props;
    return (_jsx(CustomPickersDay, { selected: false, isSelected: isSelected, day: day, className: isSelected ? "Mui-selected" : "", ...other }));
}
const CustomPickersDay = styled(PickersDay, {
    shouldForwardProp: (prop) => prop !== "isSelected",
})(({ theme, isSelected, disableHighlightToday }) => {
    return isSelected
        ? {
            "&.MuiPickersDay-root.Mui-selected": {
                backgroundColor: theme.palette.primary.main,
                color: theme.palette.primary.contrastText,
            },
        }
        : {
            "&.MuiPickersDay-root.Mui-selected": {
                backgroundColor: theme.palette.background.default,
                color: theme.palette.text.primary,
                "&.MuiPickersDay-today": !disableHighlightToday && {
                    border: `1px solid ${theme.palette.text.secondary}`,
                },
            },
        };
});
//# sourceMappingURL=MultiDateSelector.js.map